@@ -20,10 +20,12 @@
 #include "abstractunitlistmodel.h"
 #include "locationlistmodel.h"
 #include "servicelistmodel.h"
+#include "util.h"
 
+// KF
 #include <KLocalizedString>
-
-#include <QtQml>
+// Qt
+#include <QQmlEngine>
 
 
 static QObject* temperatureUnitListModelSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
@@ -32,9 +34,9 @@ static QObject* temperatureUnitListModelSingletonTypeProvider(QQmlEngine *engine
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
-        UnitItem(i18n("Celsius \302\260C"), KUnitConversion::Celsius),
-        UnitItem(i18n("Fahrenheit \302\260F"), KUnitConversion::Fahrenheit),
-        UnitItem(i18n("Kelvin K"), KUnitConversion::Kelvin)
+        UnitItem(i18nc("@item", "Celsius \302\260C"), KUnitConversion::Celsius),
+        UnitItem(i18nc("@item", "Fahrenheit \302\260F"), KUnitConversion::Fahrenheit),
+        UnitItem(i18nc("@item", "Kelvin K"), KUnitConversion::Kelvin)
     };
 
     return new AbstractUnitListModel(items);
@@ -46,10 +48,10 @@ static QObject* pressureUnitListModelSingletonTypeProvider(QQmlEngine *engine, Q
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
-        UnitItem(i18n("Hectopascals hPa"), KUnitConversion::Hectopascal),
-        UnitItem(i18n("Kilopascals kPa"), KUnitConversion::Kilopascal),
-        UnitItem(i18n("Millibars mbar"), KUnitConversion::Millibar),
-        UnitItem(i18n("Inches of Mercury inHg"), KUnitConversion::InchesOfMercury)
+        UnitItem(i18nc("@item", "Hectopascals hPa"), KUnitConversion::Hectopascal),
+        UnitItem(i18nc("@item", "Kilopascals kPa"), KUnitConversion::Kilopascal),
+        UnitItem(i18nc("@item", "Millibars mbar"), KUnitConversion::Millibar),
+        UnitItem(i18nc("@item", "Inches of Mercury inHg"), KUnitConversion::InchesOfMercury)
     };
 
     return new AbstractUnitListModel(items);
@@ -61,11 +63,11 @@ static QObject* windSpeedUnitListModelSingletonTypeProvider(QQmlEngine *engine,
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
-        UnitItem(i18n("Meters per Second m/s"), KUnitConversion::MeterPerSecond),
-        UnitItem(i18n("Kilometers per Hour km/h"), KUnitConversion::KilometerPerHour),
-        UnitItem(i18n("Miles per Hour mph"), KUnitConversion::MilePerHour),
-        UnitItem(i18n("Knots kt"), KUnitConversion::Knot),
-        UnitItem(i18n("Beaufort scale bft"), KUnitConversion::Beaufort)
+        UnitItem(i18nc("@item", "Meters per Second m/s"), KUnitConversion::MeterPerSecond),
+        UnitItem(i18nc("@item", "Kilometers per Hour km/h"), KUnitConversion::KilometerPerHour),
+        UnitItem(i18nc("@item", "Miles per Hour mph"), KUnitConversion::MilePerHour),
+        UnitItem(i18nc("@item", "Knots kt"), KUnitConversion::Knot),
+        UnitItem(i18nc("@item", "Beaufort scale bft"), KUnitConversion::Beaufort)
     };
 
     return new AbstractUnitListModel(items);
@@ -77,13 +79,21 @@ static QObject* visibilityUnitListModelSingletonTypeProvider(QQmlEngine *engine,
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
-        UnitItem(i18n("Kilometers"), KUnitConversion::Kilometer),
-        UnitItem(i18n("Miles"), KUnitConversion::Mile)
+        UnitItem(i18nc("@item", "Kilometers"), KUnitConversion::Kilometer),
+        UnitItem(i18nc("@item", "Miles"), KUnitConversion::Mile)
     };
 
     return new AbstractUnitListModel(items);
 }
 
+static QObject* utilSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
+{
+    Q_UNUSED(engine)
+    Q_UNUSED(scriptEngine)
+
+    return new Util();
+}
+
 
 void WeatherPlugin::registerTypes(const char *uri)
 {
@@ -97,6 +107,8 @@ void WeatherPlugin::registerTypes(const char *uri)
                                                     windSpeedUnitListModelSingletonTypeProvider);
     qmlRegisterSingletonType<AbstractUnitListModel>(uri, 1, 0, "VisibilityUnitListModel",
                                                     visibilityUnitListModelSingletonTypeProvider);
+    qmlRegisterSingletonType<Util>(uri, 1, 0, "Util",
+                                   utilSingletonTypeProvider);
     qmlRegisterType<LocationListModel>(uri, 1, 0, "LocationListModel");
     qmlRegisterType<ServiceListModel>(uri, 1, 0, "ServiceListModel");
 }
